pub struct KeyUpdaters { /* private fields */ }This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Responsible for managing the updaters for identity key change
Implementations
Sourceimpl KeyUpdaters
impl KeyUpdaters
Sourcepub fn add(
&mut self,
updater_type: KeyUpdaterType,
updater: Arc<dyn NotifyKeyUpdate + Sync + Send>,
)
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn add( &mut self, updater_type: KeyUpdaterType, updater: Arc<dyn NotifyKeyUpdate + Sync + Send>, )
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Add a new key updater to the list
Sourcepub fn remove(&mut self, updater_type: &KeyUpdaterType)
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn remove(&mut self, updater_type: &KeyUpdaterType)
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Remove a key updater by its key