pub struct Validator {
pub cluster_info: Arc<ClusterInfo>,
pub bank_forks: Arc<RwLock<BankForks>>,
pub blockstore: Arc<Blockstore>,
/* private fields */
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Fields
cluster_info: Arc<ClusterInfo>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
bank_forks: Arc<RwLock<BankForks>>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
blockstore: Arc<Blockstore>This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Implementations
Sourceimpl Validator
impl Validator
pub fn new( node: Node, identity_keypair: Arc<Keypair>, ledger_path: &Path, vote_account: &Pubkey, authorized_voter_keypairs: Arc<RwLock<Vec<Arc<Keypair>>>>, cluster_entrypoints: Vec<ContactInfo>, config: &ValidatorConfig, should_check_duplicate_instance: bool, rpc_to_plugin_manager_receiver: Option<Receiver<GeyserPluginManagerRequest>>, start_progress: Arc<RwLock<ValidatorStartProgress>>, socket_addr_space: SocketAddrSpace, tpu_config: ValidatorTpuConfig, admin_rpc_service_post_init: Arc<RwLock<Option<AdminRpcRequestMetadataPostInit>>>, ) -> Result<Self>
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn exit(&mut self)
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn close(self)
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn join(self)
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.